==> jc-1.4.0.tar.gz: soot/javaToJimple/JavaToJimple.h <==
// public class soot.javaToJimple.JavaToJimple

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cf4cd50123a0c94a soot_javaToJimple_JavaToJimple

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_javaToJimple_JavaToJimple_H_
#define _JC_soot_javaToJimple_JavaToJimple_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_frontend_Compiler$object;
struct _jc_polyglot_frontend_ExtensionInfo$object;
struct _jc_polyglot_frontend_Pass__24ID$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_JavaToJimple$sub_refs	_jc_soot_javaToJimple_JavaToJimple$sub_refs;
typedef struct _jc_soot_javaToJimple_JavaToJimple$sub_nonrefs	_jc_soot_javaToJimple_JavaToJimple$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_JavaToJimple$refs	_jc_soot_javaToJimple_JavaToJimple$refs;
typedef struct _jc_soot_javaToJimple_JavaToJimple$nonrefs	_jc_soot_javaToJimple_JavaToJimple$nonrefs;
typedef struct _jc_soot_javaToJimple_JavaToJimple$object	_jc_soot_javaToJimple_JavaToJimple$object;

typedef struct _jc_soot_javaToJimple_JavaToJimple$fields_struct	_jc_soot_javaToJimple_JavaToJimple$fields_struct;
typedef const struct _jc_soot_javaToJimple_JavaToJimple$vmethods	_jc_soot_javaToJimple_JavaToJimple$vmethods;
typedef const struct _jc_soot_javaToJimple_JavaToJimple$vtable	_jc_soot_javaToJimple_JavaToJimple$vtable;
typedef const struct _jc_soot_javaToJimple_JavaToJimple$vtype	_jc_soot_javaToJimple_JavaToJimple$vtype;

// Class fields structure
struct _jc_soot_javaToJimple_JavaToJimple$fields_struct {
	struct _jc_polyglot_frontend_Pass__24ID$object	*CAST__5fINSERTION;
	struct _jc_polyglot_frontend_Pass__24ID$object	*SAVE__5fAST;
};
extern _jc_soot_javaToJimple_JavaToJimple$fields_struct _jc_soot_javaToJimple_JavaToJimple$class_fields;

// Constructors
extern void _jc_soot_javaToJimple_JavaToJimple$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_JavaToJimple$object *);

// Virtual methods
extern struct _jc_object *_jc_soot_javaToJimple_JavaToJimple$method$compile$55ddb7e2c347d0bb(_jc_env *, struct _jc_soot_javaToJimple_JavaToJimple$object *, struct _jc_polyglot_frontend_Compiler$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_javaToJimple_JavaToJimple$method$initExtInfo$236addf7f76a8f67(_jc_env *, struct _jc_soot_javaToJimple_JavaToJimple$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_JavaToJimple$method_info$compile$55ddb7e2c347d0bb;
extern _jc_method _jc_soot_javaToJimple_JavaToJimple$method_info$initExtInfo$236addf7f76a8f67;

// Static methods
extern void _jc_soot_javaToJimple_JavaToJimple$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_soot_javaToJimple_JavaToJimple$vmethods {
	struct _jc_object	*(*compile$55ddb7e2c347d0bb)(_jc_env *, struct _jc_soot_javaToJimple_JavaToJimple$object *, struct _jc_polyglot_frontend_Compiler$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
	struct _jc_object	*(*initExtInfo$236addf7f76a8f67)(_jc_env *, struct _jc_soot_javaToJimple_JavaToJimple$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_javaToJimple_JavaToJimple$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_javaToJimple_JavaToJimple$vmethods	soot_javaToJimple_JavaToJimple;
};

// Vtype
struct _jc_soot_javaToJimple_JavaToJimple$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_JavaToJimple$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_JavaToJimple$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_JavaToJimple$refs {
    _jc_soot_javaToJimple_JavaToJimple$sub_refs	soot_javaToJimple_JavaToJimple;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_JavaToJimple$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_JavaToJimple$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_javaToJimple_JavaToJimple$sub_nonrefs	soot_javaToJimple_JavaToJimple;
};

// Object instance structure
struct _jc_soot_javaToJimple_JavaToJimple$object {
	_jc_soot_javaToJimple_JavaToJimple$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_JavaToJimple$vtype	*vtype;
	_jc_soot_javaToJimple_JavaToJimple$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_JavaToJimple$vtype _jc_soot_javaToJimple_JavaToJimple$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_JavaToJimple, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_JavaToJimple$class_object;

#endif	/* _JC_soot_javaToJimple_JavaToJimple_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/JavaToJimple.h <==
// public class soot.javaToJimple.JavaToJimple

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cf4cd50123a0c94a soot_javaToJimple_JavaToJimple

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_javaToJimple_JavaToJimple_H_
#define _JC_soot_javaToJimple_JavaToJimple_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_frontend_Compiler$object;
struct _jc_polyglot_frontend_ExtensionInfo$object;
struct _jc_polyglot_frontend_Pass__24ID$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_JavaToJimple$sub_refs	_jc_soot_javaToJimple_JavaToJimple$sub_refs;
typedef struct _jc_soot_javaToJimple_JavaToJimple$sub_nonrefs	_jc_soot_javaToJimple_JavaToJimple$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_JavaToJimple$refs	_jc_soot_javaToJimple_JavaToJimple$refs;
typedef struct _jc_soot_javaToJimple_JavaToJimple$nonrefs	_jc_soot_javaToJimple_JavaToJimple$nonrefs;
typedef struct _jc_soot_javaToJimple_JavaToJimple$object	_jc_soot_javaToJimple_JavaToJimple$object;

typedef struct _jc_soot_javaToJimple_JavaToJimple$fields_struct	_jc_soot_javaToJimple_JavaToJimple$fields_struct;
typedef const struct _jc_soot_javaToJimple_JavaToJimple$vmethods	_jc_soot_javaToJimple_JavaToJimple$vmethods;
typedef const struct _jc_soot_javaToJimple_JavaToJimple$vtable	_jc_soot_javaToJimple_JavaToJimple$vtable;
typedef const struct _jc_soot_javaToJimple_JavaToJimple$vtype	_jc_soot_javaToJimple_JavaToJimple$vtype;

// Class fields structure
struct _jc_soot_javaToJimple_JavaToJimple$fields_struct {
	struct _jc_polyglot_frontend_Pass__24ID$object	*CAST__5fINSERTION;
	struct _jc_polyglot_frontend_Pass__24ID$object	*SAVE__5fAST;
};
extern _jc_soot_javaToJimple_JavaToJimple$fields_struct _jc_soot_javaToJimple_JavaToJimple$class_fields;

// Constructors
extern void _jc_soot_javaToJimple_JavaToJimple$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_JavaToJimple$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_javaToJimple_JavaToJimple$method$compile$55ddb7e2c347d0bb(_jc_env *, struct _jc_soot_javaToJimple_JavaToJimple$object *, struct _jc_polyglot_frontend_Compiler$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_javaToJimple_JavaToJimple$method$initExtInfo$236addf7f76a8f67(_jc_env *, struct _jc_soot_javaToJimple_JavaToJimple$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_JavaToJimple$method_info$compile$55ddb7e2c347d0bb;
extern _jc_method _jc_soot_javaToJimple_JavaToJimple$method_info$initExtInfo$236addf7f76a8f67;

// Static methods
extern void _jc_soot_javaToJimple_JavaToJimple$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_javaToJimple_JavaToJimple$vmethods {
	struct _jc_object	*(*compile$55ddb7e2c347d0bb)(_jc_env *, struct _jc_soot_javaToJimple_JavaToJimple$object *, struct _jc_polyglot_frontend_Compiler$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*initExtInfo$236addf7f76a8f67)(_jc_env *, struct _jc_soot_javaToJimple_JavaToJimple$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_javaToJimple_JavaToJimple$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_javaToJimple_JavaToJimple$vmethods	soot_javaToJimple_JavaToJimple;
};

// Vtype
struct _jc_soot_javaToJimple_JavaToJimple$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_JavaToJimple$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_JavaToJimple$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_JavaToJimple$refs {
    _jc_soot_javaToJimple_JavaToJimple$sub_refs	soot_javaToJimple_JavaToJimple;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_JavaToJimple$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_JavaToJimple$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_javaToJimple_JavaToJimple$sub_nonrefs	soot_javaToJimple_JavaToJimple;
};

// Object instance structure
struct _jc_soot_javaToJimple_JavaToJimple$object {
	_jc_soot_javaToJimple_JavaToJimple$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_JavaToJimple$vtype	*vtype;
	_jc_soot_javaToJimple_JavaToJimple$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_JavaToJimple$vtype _jc_soot_javaToJimple_JavaToJimple$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_JavaToJimple, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_JavaToJimple$class_object;

#endif	/* _JC_soot_javaToJimple_JavaToJimple_H_ */
